@@ -8,13 +8,7 @@ import os
 
 from appdirs import AppDirs
 
-try:
-    # noinspection PyCompatibility
-    from importlib.metadata import version
-except ModuleNotFoundError:
-    # noinspection PyUnresolvedReferences
-    # <3.8 backport
-    from importlib_metadata import version
+from importlib.metadata import version
 
 try:
     __version__ = version(__name__)
@@ -22,7 +16,8 @@ except Exception:
     __version__ = None
 
 
-__chromium_revision__ = '588429'
+# old chrome version panic upon launching - this one may not match the base puppeteer version, but at least it launches
+__chromium_revision__ = '1181205'
 __base_puppeteer_version__ = 'v1.6.0'
 __pyppeteer_home__ = os.environ.get('PYPPETEER_HOME', AppDirs('pyppeteer').user_data_dir)  # type: str
 DEBUG = False
@@ -30,7 +25,6 @@ DEBUG = False
 from pyppeteer.launcher import connect, executablePath, launch, defaultArgs  # noqa: E402; noqa: E402
 
 version = __version__
-version_info = tuple(int(i) for i in version.split('.'))
 
 __all__ = [
     'connect',
@@ -38,5 +32,4 @@ __all__ = [
     'executablePath',
     'defaultArgs',
     'version',
-    'version_info',
 ]
